==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/lt-LT/admin/hardware/general.php <==
<?php

return [
    'about_assets_title'           => 'Apie turtą',
    'about_assets_text'            => 'Turtas, tai daiktai, kuriuos galima sekti pagal serijinį ar inventorinį numerį. Įprastai, tai yra didesnės vertės daiktai, kurių individualus identifikavimas yra svarbus.',
    'archived'  				=> 'Archyvuotas',
    'asset'  					=> 'Turtas',
    'bulk_checkout'             => 'Išduoti kelis',
    'bulk_checkin'              => 'Bulk Checkin',
    'checkin'  					=> 'Paimti turtą',
    'checkout'  				=> 'Išduoti turtą',
    'clone'  					=> 'Klonuoti turtą',
    'deployable'  				=> 'Galima naudoti',
    'deleted'  					=> 'Šis turtas buvo panaikintas.',
    'delete_confirm'            => 'Ar tikrai norite panaikinti šį turtą?',
    'edit'  					=> 'Redaguoti turtą',
    'model_deleted'  			=> 'Šis turto modelis buvo panaikintas. Pirmiau turite atkurti modelį, tada galėsite atkurti patį turtą.',
    'model_invalid'             => 'Šiam turtui šis modelis netinka.',
    'model_invalid_fix'         => 'Turtas turi būti atnaujintas parenkant tinkamą turto modelį, kad jį būtų galima išduoti/paimti ar audituoti.',
    'requestable'               => 'Užsakomas',
    'requested'				    => 'Užsakytas',
    'not_requestable'           => 'Neužsakomas',
    'requestable_status_warning' => 'Nekeisti užsakomo turto būsenos',
    'restore'  					=> 'Atkurti turtą',
    'pending'  					=> 'Ruošiamas',
    'undeployable'  			=> 'Neišduotinas',
    'undeployable_tooltip'  	=> 'Šis turtas yra pažymėtas kaip neišduotinas, todėl šiuo metu jo negalima išduoti.',
    'view'  					=> 'Peržiūrėti turtą',
    'csv_error' => 'Jūsų CSV faile yra klaida:',
    'import_text' => '<p>Įkelkite CSV, kuriame yra turto istorija. Turtas ir naudotojai PRIVALO būti sistemoje, kitaip jie bus praleisti. Atliekant istorijos importavimą, turtas yra susiejamas pagal inventorinį numerį. Bus bandoma rasti atitinkantį naudotoją pagal jūsų pateiktą naudotojo vardą ir žemiau pasirinktus kriterijus. Jei nepasirinksite jokio kriterijaus, tiesiog bus bandoma atlikti susiejimą pagal naudotojo vardo formatą, kurį pasirinkote <code>Administratorius &gt; Bendrieji nustatymai</code> nustatymuose.</p><p>Į CSV įtraukti laukai turi atitikti antraštes: <strong>Inventorinis numeris, Pavadinimas, Išdavimo data, Paėmimo data</strong>. Visi papildomi laukai bus ignoruojami. </p><p>Paėmimo data: tuščia arba nurodyta būsima paėmimo data –  turtas bus priskirtas susijusiam naudotojui. Nepasirinkus stulpelio „Paėmimo data“, bus sukurta paėmimo data su šiandienos data.</p>
    ',
    'csv_import_match_f-l' => 'Bandyti susieti naudotojus pagal formatą <strong>vardas.pavardė</strong> (<code>vardenis.pavardenis</code>)',
    'csv_import_match_initial_last' => 'Bandyti susieti naudotojus pagal formatą <strong>pirmoji vardo raidė ir pavardė</strong> (<code>vpavardenis</code>)',
    'csv_import_match_first' => 'Bandyti susieti naudotojus pagal formatą <strong>vardas</strong> (<code>vardenis</code>)',
    'csv_import_match_email' => 'Bandyti susieti naudotojus naudojant <strong>el. paštą</strong>, kaip naudotojo vardą',
    'csv_import_match_username' => 'Bandyti susieti naudotojus pagal <strong>naudotojo vardą</strong>',
    'error_messages' => 'Klaidos pranešimai:',
    'success_messages' => 'Sėkmės pranešimai:',
    'alert_details' => 'Peržiūrėkite žemiau pateiktą informaciją.',
    'custom_export' => 'Pasirinktinis eksportavimas',
    'mfg_warranty_lookup' => ':manufacturer garantijos būsenos peržiūra',
    'user_department' => 'Naudotojo skyrius',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/lt-LT/admin/hardware/general.php <==
<?php

return [
    'about_assets_title'           => 'Apie turtą',
    'about_assets_text'            => 'Turtas, tai daiktai, kuriuos galima sekti pagal serijinį ar inventorinį numerį. Įprastai, tai yra didesnės vertės daiktai, kurių individualus identifikavimas yra svarbus.',
    'archived'  				=> 'Archyvuotas',
    'asset'  					=> 'Turtas',
    'bulk_checkout'             => 'Išduoti kelis',
    'bulk_checkin'              => 'Paimti kelis',
    'checkin'  					=> 'Paimti turtą',
    'checkout'  				=> 'Išduoti turtą',
    'clear'                     => 'Išvalyti',
    'clone'  					=> 'Klonuoti turtą',
    'deployable'  				=> 'Galima naudoti',
    'deleted'  					=> 'Šis turtas buvo panaikintas.',
    'delete_confirm'            => 'Ar tikrai norite panaikinti šį turtą?',
    'edit'  					=> 'Redaguoti turtą',
    'model_deleted'  			=> 'Šis turto modelis buvo panaikintas. Pirmiau turite atkurti modelį, tada galėsite atkurti patį turtą.',
    'model_invalid'             => 'Šiam turtui šis modelis netinka.',
    'model_invalid_fix'         => 'Turtas turi būti atnaujintas parenkant tinkamą turto modelį, kad jį būtų galima išduoti/paimti ar audituoti.',
    'requestable'               => 'Užsakomas',
    'requested'				    => 'Užsakytas',
    'not_requestable'           => 'Neužsakomas',
    'requestable_status_warning' => 'Nekeisti užsakomo turto būsenos',
    'require_serial'       => 'Reikalauti serijinio numerio',
    'require_serial_help'       => 'Kuriant naują šio modelio turtą reikės įvesti jo serijinį numerį.',
    'restore'  					=> 'Atkurti turtą',
    'pending'  					=> 'Ruošiamas',
    'undeployable'  			=> 'Neišduotinas',
    'undeployable_tooltip'  	=> 'Šis turtas yra pažymėtas kaip neišduotinas, todėl šiuo metu jo negalima išduoti.',
    'view'  					=> 'Peržiūrėti turtą',
    'csv_error' => 'Jūsų CSV faile yra klaida:',
    'import_text' => '<p>Įkelkite CSV, kuriame yra turto istorija. Turtas ir naudotojai PRIVALO būti sistemoje, kitaip jie bus praleisti. Atliekant istorijos importavimą, turtas yra susiejamas pagal inventorinį numerį. Bus bandoma rasti atitinkantį naudotoją pagal jūsų pateiktą naudotojo vardą ir žemiau pasirinktus kriterijus. Jei nepasirinksite jokio kriterijaus, tiesiog bus bandoma atlikti susiejimą pagal naudotojo vardo formatą, kurį pasirinkote <code>Administratorius &gt; Bendrieji nustatymai</code> nustatymuose.</p><p>Į CSV įtraukti laukai turi atitikti antraštes: <strong>Inventorinis numeris, Pavadinimas, Išdavimo data, Paėmimo data</strong>. Visi papildomi laukai bus ignoruojami. </p><p>Paėmimo data: tuščia arba nurodyta būsima paėmimo data –  turtas bus priskirtas susijusiam naudotojui. Nepasirinkus stulpelio „Paėmimo data“, bus sukurta paėmimo data su šiandienos data.</p>    ',
    'csv_import_match_f-l' => 'Bandyti susieti naudotojus pagal formatą <strong>vardas.pavardė</strong> (<code>vardenis.pavardenis</code>)',
    'csv_import_match_initial_last' => 'Bandyti susieti naudotojus pagal formatą <strong>pirmoji vardo raidė ir pavardė</strong> (<code>vpavardenis</code>)',
    'csv_import_match_first' => 'Bandyti susieti naudotojus pagal formatą <strong>vardas</strong> (<code>vardenis</code>)',
    'csv_import_match_email' => 'Bandyti susieti naudotojus naudojant <strong>el. paštą</strong>, kaip naudotojo vardą',
    'csv_import_match_username' => 'Bandyti susieti naudotojus pagal <strong>naudotojo vardą</strong>',
    'error_messages' => 'Klaidos pranešimai:',
    'success_messages' => 'Sėkmės pranešimai:',
    'alert_details' => 'Peržiūrėkite žemiau pateiktą informaciją.',
    'custom_export' => 'Pasirinktinis eksportavimas',
    'mfg_warranty_lookup' => ':manufacturer garantijos būsenos peržiūra',
    'user_department' => 'Naudotojo skyrius',
];
